"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Storage {
    constructor(type = "default") {
        this.prefix = type;
    }
    get(key, defaultValue) {
        const value = localStorage.getItem(this.getKey(key));
        if (value === null) {
            return defaultValue;
        }
        try {
            return JSON.parse(value);
        }
        catch (_a) {
            return defaultValue;
        }
    }
    set(key, value) {
        const serializedValue = JSON.stringify(value);
        localStorage.setItem(this.getKey(key), serializedValue);
    }
    remove(key) {
        localStorage.removeItem(this.getKey(key));
    }
    clear() {
        for (let i = 0; i < localStorage.length; i++) {
            const key = localStorage.key(i);
            if (key && key.startsWith(`${this.prefix}:`)) {
                localStorage.removeItem(key);
            }
        }
    }
    getKey(key) {
        return `${this.prefix}:${key}`;
    }
}
exports.default = Storage;
